class ChannelController < ApplicationController

  layout 'general'  
  

  def visit
    @page_class = params[:style] if params[:style]

    unless session[:login] || params[:login]
      render 'channel/get_login'
      return false
    end

    if params[:login]
      if (params[:login].length < 2 || params[:login].length > 25)
        flash[:error] = "Enter a sensible login please"
        render 'channel/get_login'
        return false        
      end
      session[:login] = params[:login]
    end

    @user = User.find_or_create_by_login(session[:login])
    @channel = Channel.find_or_create_by_name_and_title_and_topic(params[:id], "wow","wow")

    unless @channel.users.include?(@user)
      @user.joins_channel(@channel)
      @channel.users.push_with_attributes(@user, { :last_seen => Time.now })
    end
  end

  # Post a user's message to a channel
  def say
    return false unless request.xhr?
    get_channel_and_user
    
    # Get the message
    message = params[:message]
    return false unless message
    
    if message.match(/^\/\w+/)
      # It's an IRC style command
      command, arguments = message.scan(/^\/(\w+)(.+?)$/).flatten
      logger.info(command)
      case command
        when 'me'
          @user.action_in_channel(@channel, arguments)
          @message = Message.find(:first, :order => "id DESC", :conditions => ["sender_id = ?", @user.id])
        when 'nick'
          #session[:login] = arguments
        when 'join'
          @aux_command = %(window.location = "channel/_visit/#{arguments}";)
        else
          return false
      end
    else
      @user.say_in_channel(@channel, message)
      @message = Message.find(:first, :order => "id DESC", :conditions => ["sender_id = ?", @user.id])
    end
    
    render :layout => false
  end

  # Get the latest messages since the user last got any
  def get_latest_messages
    return false unless request.xhr?
    get_channel_and_user
    @messages = @channel.messages.since(session[:last_retrieval])
    session[:last_retrieval] = Time.now
    render :layout => false
  end
  
  # Get a list of users for the channel and clean up any who left
  def get_user_list
    return false unless request.xhr?
    get_channel_and_user
    
    # Tell the database we're still alive
    @channel.users.delete(@user)
    @channel.users.push_with_attributes(@user, { :last_seen => Time.now })
    
    # Announce any users who just left
    if @channel.users_just_left
      for user in @channel.users_just_left
        user.leaves_channel(@channel)
      end
    end
    
    # Do a clean up of users in the channel
    @channel.users.cleanup
    render :layout => false
  end
  
  
  private
  
  # Get channel and user info that most methods use
  def get_channel_and_user
    @user = User.find_by_login(session[:login])    
    @channel = Channel.find_by_name(params[:channel_name])  
  end
end
