class ProjectsController < ApplicationController
  scaffold :project
  before_filter :login_required
  
  def index
    list
    render :action => 'list'
    
  end

  # GETs should be safe (see http://www.w3.org/2001/tag/doc/whenToUseGet.html)
  verify :method => :post, :only => [ :destroy, :create, :update ],
         :redirect_to => { :action => :list }
 
  def list
	#list all projects of the current user (admin or member)
	@user = @session['user']
	@projects = Project.find(:all, :conditions => ["user_id =?", @user.id])  
        users_projects = UsersProjects.find(:all, :conditions => ['user_id =?', @user.id])
        #combine all the user's projects into one array
        users_projects.length.times { |n| @projects[n + @projects.length] = Project.find(users_projects[n].project_id) }
	
  end

   
  #list users of the project
  def show
    @project = Project.find(params[:id])
    users_projects = UsersProjects.find(:all, :conditions => ['project_id =?', @project.id])
    @users = Array.new
    users_projects.length.times { |n| @users[n] = User.find(users_projects[n].user_id) }
    
    #not allow to view other people's projects
    if @project.user_id != @session['user'].id
      flash[:notice] = 'You cannot view this project.'
      redirect_to :action => 'list', :id => @project
    end
  end

  #create a new project
  def new
    @project = Project.new
       
  end

  def create
    @project = Project.new(params[:project])
    #set the project's user_id to the current user
    @project.user_id = @session['user'].id
    #create a default root folder to extend document tree from
    root_document = Document.new(params[:document])   
    
    if @project.save
	root_document.name = @project.title
	root_document.project_id = @project.id
	root_document.save
      flash[:notice] = 'Project was successfully created.'
      redirect_to :action => 'list'
    else
      render :action => 'new'
    end
  end

  #start working on the project
  def edit
    @project = Project.find(params[:project])
    @user = User.find(params[:user])
    #set cookies so that we can get the current project in other controllers
    @session['project'] = @project
    @session['document'] = Document.find(:first, :conditions=> ["project_id = ? AND parent_id IS NULL", @project.id])
    redirect_to :controller => 'account', :action => 'main', :project => @project.id, :user =>@user.id
    
  end

  def update
    @project = Project.find(params[:id])
    if @project.update_attributes(params[:project])  
	
      flash[:notice] = 'Project was successfully updated.'
      redirect_to :action => 'show', :id => @project
    else
      render :action => 'edit'
    end
  end

#only the owner can destroy a project 
def destroy
    @project = Project.find(params[:id])
    if @project.user_id != @session['user'].id
      flash[:notice] = 'You cannot destroy this project.'
      redirect_to :action => 'list', :id => @project
    end
    #destroy the project and all its document, also clear the users_projects relationship
    Project.find(params[:id]).destroy
    Document.find(:all, :conditions => ["project_id =?", @project.id]).each {|doc| Document.find(doc.id).destroy}
    UsersProjects.find(:all, :conditions => ["project_id =?", @project.id]).each {|u_p| UsersProjects.find(u_p.id).destroy}
    redirect_to :action => 'list'
  end
end
